==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/id/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Pengguna telah membatalkan permintaan item di situs web',
    'a_user_requested' => 'Pengguna telah meminta item di situs web',
    'accessory_name' => 'Nama Aksesori:',
    'additional_notes' => 'Catatan Tambahan:',
    'admin_has_created' => 'Administrator telah membuat akun untuk Anda di: situs web web.',
    'asset' => 'Aset:',
    'asset_name' => 'Nama Aset:',
    'asset_requested' => 'Permintaan aset',
    'asset_tag' => 'Tag Aset',
    'assigned_to' => 'Ditugaskan untuk',
    'best_regards' => 'Salam Hormat,',
    'canceled' => 'Dibatalkan:',
    'checkin_date' => 'Tanggal Checkin:',
    'checkout_date' => 'Tanggal keluar:',
    'click_to_confirm' => 'Silahkan klik pada link berikut untuk mengkonfirmasi: akun web Anda:',
    'click_on_the_link_accessory' => 'Silahkan klik pada link di bagian bawah untuk mengkonfirmasi bahwa Anda telah menerima aksesori.',
    'click_on_the_link_asset' => 'Silahkan klik pada link di bagian bawah untuk mengkonfirmasi bahwa Anda telah menerima aset tersebut.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY saat ini',
    'Days' => 'Hari',
    'days' => 'Hari',
    'expecting_checkin_date' => 'Tanggal Checkin yang Diharapkan:',
    'expires' => 'Kadaluarsa',
    'Expiring_Assets_Report' => 'Laporan Aktiva Kedaluwarsa',
    'Expiring_Licenses_Report' => 'Laporan Lisensi yang Berakhir',
    'hello' => 'Halo',
    'hi' => 'Hai',
    'i_have_read' => 'Saya telah membaca dan menyetujui persyaratan penggunaan, dan telah menerima barang ini.',
    'item' => 'Barang:',
    'Item_Request_Canceled' => 'Permintaan Barang Dibatalkan',
    'Item_Requested' => 'Barang yang diminta',
    'link_to_update_password' => 'Silahkan klik pada link berikut untuk mengupdate: password web anda:',
    'login_first_admin' => 'Login ke instalasi Snipe-IT baru Anda dengan menggunakan kredensial di bawah ini:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Laporan Inventaris Rendah',
    'min_QTY' => 'Min QTY',
    'name' => 'Nama',
    'new_item_checked' => 'Item baru telah diperiksa berdasarkan nama Anda, rinciannya ada di bawah.',
    'password' => 'Password:',
    'password_reset' => 'Reset Password',

    'read_the_terms' => 'Silahkan baca syarat penggunaan di bawah ini.',
    'read_the_terms_and_click' => 'Harap baca persyaratan penggunaan di bawah ini, dan klik tautan di bagian bawah untuk memastikan bahwa Anda membaca dan menyetujui persyaratan penggunaan, dan telah menerima aset tersebut.',
    'requested' => 'Diminta:',
    'reset_link' => 'Tautan Reset Sandi Anda',
    'reset_password' => 'Klik di sini untuk mengatur ulang kata sandi Anda:',
    'serial' => 'Serial',
    'supplier' => 'Pemasok',
    'tag' => 'Menandai',
    'test_email' => 'Uji Email dari Snipe-IT',
    'test_mail_text' => 'Ini adalah ujian dari Snipe-IT Asset Management System. Jika Anda mendapatkan ini, surat bekerja :)',
    'the_following_item' => 'Item berikut telah diperiksa:',
    'low_inventory_alert' => 'Ada :count item yang di bawah minimum persediaan atau akan segera habis.|Ada :count item yang di bawah minimum persediaan atau akan segera habis.',
    'assets_warrantee_alert' => 'Ada :count aset yang masa garansinya tinggal :threshold hari lagi.|Ada :count aset yang garansinya tinggal :threshold hari lagi.',
    'license_expiring_alert' => 'Ada :count lisensi yang masa berlakunya akan habis dalam :threshold hari.|Ada :count lisensi yang masa berlakunya akan habis dalam :threshold hari.',
    'to_reset' => 'Untuk mereset password web anda, lengkapi form ini:',
    'type' => 'Mengetik',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Pengguna',
    'username' => 'Nama Pengguna',
    'welcome' => 'Selamat datang: nama',
    'welcome_to' => 'Selamat Datang di: web!',
    'your_credentials' => 'Kredensial Snipe-IT Anda',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/id/mail.php <==
<?php

return [
    'a_user_canceled' => 'Pengguna telah membatalkan permintaan item di situs web',
    'a_user_requested' => 'Pengguna telah meminta item di situs web',
    'accessory_name' => 'Nama Aksesori:',
    'additional_notes' => 'Catatan Tambahan:',
    'admin_has_created' => 'Administrator telah membuat akun untuk Anda di: situs web web.',
    'asset' => 'Aset:',
    'asset_name' => 'Nama Aset:',
    'asset_requested' => 'Permintaan aset',
    'asset_tag' => 'Tag Aset',
    'assigned_to' => 'Ditugaskan untuk',
    'best_regards' => 'Salam Hormat,',
    'canceled' => 'Dibatalkan:',
    'checkin_date' => 'Tanggal Checkin:',
    'checkout_date' => 'Tanggal keluar:',
    'click_to_confirm' => 'Silahkan klik pada link berikut untuk mengkonfirmasi: akun web Anda:',
    'click_on_the_link_accessory' => 'Silahkan klik pada link di bagian bawah untuk mengkonfirmasi bahwa Anda telah menerima aksesori.',
    'click_on_the_link_asset' => 'Silahkan klik pada link di bagian bawah untuk mengkonfirmasi bahwa Anda telah menerima aset tersebut.',
    'Confirm_Asset_Checkin' => 'Konfirmasi check-in Aset',
    'Confirm_Accessory_Checkin' => 'Konfirmasi check-in Aksesoris',
    'Confirm_accessory_delivery' => 'Konfirmasi pengiriman Aksesoris',
    'Confirm_license_delivery' => 'Konfirmasi pengiriman Lisensi',
    'Confirm_asset_delivery' => 'Konfirmasi pengiriman Aset',
    'Confirm_consumable_delivery' => 'Konfirmasi pengiriman Habis Pakai',
    'current_QTY' => 'QTY saat ini',
    'Days' => 'Hari',
    'days' => 'Hari',
    'expecting_checkin_date' => 'Tanggal Checkin yang Diharapkan:',
    'expires' => 'Kadaluarsa',
    'Expiring_Assets_Report' => 'Laporan Aktiva Kedaluwarsa',
    'Expiring_Licenses_Report' => 'Laporan Lisensi yang Berakhir',
    'hello' => 'Halo',
    'hi' => 'Hai',
    'i_have_read' => 'Saya telah membaca dan menyetujui persyaratan penggunaan, dan telah menerima barang ini.',
    'item' => 'Barang:',
    'Item_Request_Canceled' => 'Permintaan Barang Dibatalkan',
    'Item_Requested' => 'Barang yang diminta',
    'link_to_update_password' => 'Silahkan klik pada link berikut untuk mengupdate: password web anda:',
    'login_first_admin' => 'Login ke instalasi Snipe-IT baru Anda dengan menggunakan kredensial di bawah ini:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Laporan Inventaris Rendah',
    'min_QTY' => 'Min QTY',
    'name' => 'Nama',
    'new_item_checked' => 'Item baru telah diperiksa berdasarkan nama Anda, rinciannya ada di bawah.',
    'password' => 'Password:',
    'password_reset' => 'Reset Password',

    'read_the_terms' => 'Silahkan baca syarat penggunaan di bawah ini.',
    'read_the_terms_and_click' => 'Harap baca persyaratan penggunaan di bawah ini, dan klik tautan di bagian bawah untuk memastikan bahwa Anda membaca dan menyetujui persyaratan penggunaan, dan telah menerima aset tersebut.',
    'requested' => 'Diminta:',
    'reset_link' => 'Tautan Reset Sandi Anda',
    'reset_password' => 'Klik di sini untuk mengatur ulang kata sandi Anda:',
    'serial' => 'Serial',
    'supplier' => 'Pemasok',
    'tag' => 'Menandai',
    'test_email' => 'Uji Email dari Snipe-IT',
    'test_mail_text' => 'Ini adalah ujian dari Snipe-IT Asset Management System. Jika Anda mendapatkan ini, surat bekerja :)',
    'the_following_item' => 'Item berikut telah diperiksa:',
    'low_inventory_alert' => 'Ada :count item yang di bawah minimum persediaan atau akan segera habis.|Ada :count item yang di bawah minimum persediaan atau akan segera habis.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Ada :count lisensi yang masa berlakunya akan habis dalam :threshold hari.|Ada :count lisensi yang masa berlakunya akan habis dalam :threshold hari.',
    'to_reset' => 'Untuk mereset password web anda, lengkapi form ini:',
    'type' => 'Mengetik',
    'upcoming-audits' => 'Ada :count aset yang akan diaudit dalam :threshold hari.|Ada :count aset yang akan diaudit dalam :threshold hari.',
    'user' => 'Pengguna',
    'username' => 'Nama Pengguna',
    'welcome' => 'Selamat datang: nama',
    'welcome_to' => 'Selamat Datang di: web!',
    'your_credentials' => 'Kredensial Snipe-IT Anda',
    'Accessory_Checkin_Notification' => 'Aksesoris Kembali',
    'Asset_Checkin_Notification' => 'Aset Kembali',
    'License_Checkin_Notification' => 'Lisensi Kembali',
    'Expected_Checkin_Report' => 'Laporan check-in aset yang diharapkan',
    'Expected_Checkin_Notification' => 'Pengingat: :name mendekati batas waktu check-in [Dikembalikan]',
    'Expected_Checkin_Date' => 'Aset yang check out untuk Anda akan check in kembali pada :date',
    'your_assets' => 'Lihat Aset Anda',
];
